Index: wp-includes/post-template.php
===================================================================
--- wp-includes/post-template.php	(revision 27018)
+++ wp-includes/post-template.php	(working copy)
@@ -304,8 +304,9 @@
 /**
  * Retrieve the classes for the post div as an array.
  *
  * The class names are add are many. If the post is a sticky, then the 'sticky'
  * class name. The class 'hentry' is always added to each post. For each
  * category, the class will be added with 'category-' with category slug is
  * added. The tags are the same way as the categories with 'tag-' before the tag
  * slug. All classes are passed through the filter, 'post_class' with the list
@@ -341,6 +342,13 @@
 		else
 			$classes[] = 'format-standard';
 	}
+	
+	// Post Thumbnail, but we need to check for theme support before we call the function
+	if ( current_theme_supports( 'post-thumbnails' ) ) {
+		if ( ! post_password_required( $post->ID ) && has_post_thumbnail( $post->ID ) ) {
+			$classes[] = 'post-thumbnail';
+		}
+	}
 
 	// post requires password
 	if ( post_password_required($post->ID) )
@@ -304,8 +304,9 @@
  * Retrieve the classes for the post div as an array.
  *
- * The class names are add are many. If the post is a sticky, then the 'sticky'
- * class name. The class 'hentry' is always added to each post. For each
+ * The class names are many. If the post is a sticky, then the 'sticky'
+ * class name. The class 'hentry' is always added to each post. If the post has a
+ * post thumbnail, 'post-thumbnail' is added as a class. For each
  * category, the class will be added with 'category-' with category slug is
  * added. The tags are the same way as the categories with 'tag-' before the tag
